Name:          libhtp
Version:       0.5.6
Release:       1%{?dist}

Summary:       Security-aware parser for the HTTP protocol and the related bits and pieces
License:       BSD
URL:           http://www.libhtp.org

# Upstream doesn't publish release tarballs yet, so we make one:
#     $ git clone git://github.com/ironbee/libhtp.git && cd libhtp
#     $ git archive --format=tar --prefix=libhtp-0.5.6/ 0.5.6 | xz -z >libhtp-0.5.6.tar.xz
Source0:       %{name}-%{version}.tar.xz

# Upstream doesn't publish release tarballs yet, so we need the autotools stuff
BuildRequires: autoconf automake libtool

BuildRequires: zlib-devel
BuildRequires: doxygen

%description
LibHTP is a security-aware parser for the HTTP protocol and the related bits
and pieces. The goals of the project, in the order of importance, are as
follows:
1. Completeness of coverage;
2. Permissive parsing;
3. Awareness of evasion techniques;
4. Performance;


%package devel
Summary:       Development headers and libraries for %{name}
Requires:      %{name}%{?_isa} = %{version}-%{release}

%description devel
Development headers and libraries for %{name}.


%package doc
Summary:       Documentation for %{name}
Requires:      %{name} = %{version}-%{release}
BuildArch:     noarch

%description doc
Documentation (in HTML, Latex and PDF formats) for %{name}.


%prep
%setup -q


%build
# Upstream doesn't publish release tarballs yet, so we need to run autoreconf
autoreconf -i

%configure --disable-static \
           --with-doxygen=doxygen
make %{?_smp_mflags}

# Make it easier to install the HTML docs
sed -i 's|^\(HTML_OUTPUT *=\).*|\1|' docs/doxygen.conf

# Build the documentation
make doxygen

%install
make install DESTDIR=%{buildroot}

# Remove installed libtools files
find %{buildroot} -name '*.la' -exec rm -f '{}' \;


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%doc AUTHORS COPYING LICENSE README
%{_libdir}/%{name}*.so.*

%files devel
%{_libdir}/%{name}.so
%{_includedir}/htp
%{_libdir}/pkgconfig/htp.pc

%files doc
%doc docs/doxygen/html
%doc docs/doxygen/latex


%changelog
* Fri Jul 26 2013 Mathieu Bridon <bochecha@fedoraproject.org> - 0.5.6-1
- New upstream release: 0.5.6.

* Wed May 22 2013 Mathieu Bridon <bochecha@fedoraproject.org> - 0.5.2-1
- New upstream release: 0.5.2.

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Aug 17 2012 Mathieu Bridon <bochecha@fedoraproject.org> - 0.3.0-1
- Update to 0.3.0 release.
- License changed from ASL 2.0 to BSD.

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.0-0.5.20120126.git53e5901
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 27 2012 Mathieu Bridon <bochecha@fedoraproject.org> - 0.3.0-0.4.20120126.git53e5901
- Fix doc installing (the previous way worked on Fedora but not on EPEL 6).

* Thu Jan 26 2012 Mathieu Bridon <bochecha@fedoraproject.org> - 0.3.0-0.3.20120126.git53e5901
- New upstream VCS snapshot, including bug fixes, better unit tests and
  integration of the documentation to the build/install tool chain.
- Build the API docs and add it to the new -doc subpackage.

* Thu Jan 26 2012 Mathieu Bridon <bochecha@fedoraproject.org> - 0.3.0-0.2.20111021.git537ac17
- Fix a few issues raised during package review:
  - Remove the useless Group tag for the -devel subpackage.
  - Fix requirement of the main package in the -devel subpackage.
  - Remove the useless %%defattr lines.
  - Add the README and NOTICE files as documentation.
  - Remove the documentation files from -devel subpackage if they are already
    included in the main package, since the former requires the latter anyway.
- Use the buildroot macro rather than the RPM_BUILD_ROOT variable, to be
  consistent (I'm not using any other variables, only macros).

* Fri Oct 21 2011 Mathieu Bridon <bochecha@fedoraproject.org> - 0.3.0-0.1.20111021.git537ac17
- New upstream snapshot, to fix the two issues I was working around in the spec:
  - Spurious executable permissions on *.c and *.h files
    https://github.com/ironbee/libhtp/issues/17
  - Wrong end-of-line encoding for COPYING
    https://github.com/ironbee/libhtp/issues/18
- Remove useless Group tag, I like my spec files uncluttered.

* Tue Oct 04 2011 Mathieu Bridon <bochecha@fedoraproject.org> - 0.3.0-0.1.20111010.git198963d
- Initial packaging.
